==> localstack-ext-0.13.0.13.tar.gz: localstack-ext-0.13.0.13/localstack_ext/services/cloudformation/models/ecr.py <==
from localstack.services.cloudformation.service_models import GenericBaseModel
evLyD=staticmethod
evLyl=None
evLyM=False
from localstack.utils.aws import aws_stack
from localstack_ext.utils.aws import aws_utils
class ECRRepository(GenericBaseModel):
 @evLyD
 def cloudformation_type():
  return "AWS::ECR::Repository"
 def get_physical_resource_id(self,attribute,**kwargs):
  repo_name=self.props.get("RepositoryName")
  if attribute=="Arn":
   return aws_utils.get_ecr_repository_arn(repo_name)
  return repo_name
 def fetch_state(self,stack_name,resources):
  client=aws_stack.connect_to_service("ecr")
  props=self.props
  repo_name=props.get("RepositoryName")
  registry_id=props.get("LifecyclePolicy",{}).get("RegistryId")
  kwargs={"registryId":registry_id}if registry_id else{}
  result=client.describe_repositories(repositoryNames=[repo_name],**kwargs).get("repositories",[])
  return(result or[evLyl])[0]
 @evLyD
 def get_deploy_templates():
  def _create_params(params,**kwargs):
   encryption_type=params.get("EncryptionConfiguration",{}).get("EncryptionType","AES-256")
   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",evLyM)},"encryptionConfiguration":{"encryptionType":encryption_type}}
   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not evLyl):
    response["encryptionConfiguration"]["kmsKey"]=params["EncryptionConfiguration"]["KmsKey"]
   return response
  result={"create":{"function":"create_repository","parameters":_create_params},"delete":{"function":"delete_repository","parameters":{"repositoryName":"RepositoryName"}}}
  return result
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.13.0.14.tar.gz: localstack-ext-0.13.0.14/localstack_ext/services/cloudformation/models/ecr.py <==
from localstack.services.cloudformation.service_models import GenericBaseModel
IcgHC=staticmethod
IcgHu=None
IcgHr=False
from localstack.utils.aws import aws_stack
from localstack_ext.utils.aws import aws_utils
class ECRRepository(GenericBaseModel):
 @IcgHC
 def cloudformation_type():
  return "AWS::ECR::Repository"
 def get_physical_resource_id(self,attribute,**kwargs):
  repo_name=self.props.get("RepositoryName")
  if attribute=="Arn":
   return aws_utils.get_ecr_repository_arn(repo_name)
  return repo_name
 def fetch_state(self,stack_name,resources):
  client=aws_stack.connect_to_service("ecr")
  props=self.props
  repo_name=props.get("RepositoryName")
  registry_id=props.get("LifecyclePolicy",{}).get("RegistryId")
  kwargs={"registryId":registry_id}if registry_id else{}
  result=client.describe_repositories(repositoryNames=[repo_name],**kwargs).get("repositories",[])
  return(result or[IcgHu])[0]
 @IcgHC
 def get_deploy_templates():
  def _create_params(params,**kwargs):
   encryption_type=params.get("EncryptionConfiguration",{}).get("EncryptionType","AES-256")
   response={"repositoryName":params["RepositoryName"],"tags":params.get("Tags",[]),"imageTagMutability":params.get("ImageTagMutability","MUTABLE"),"imageScanningConfiguration":{"scanOnPush":params.get("ImageScanningConfiguration",{}).get("ScanOnPush",IcgHr)},"encryptionConfiguration":{"encryptionType":encryption_type}}
   if(encryption_type=="KMS" and params.get("EncryptionConfiguration",{}).get("KmsKey")is not IcgHu):
    response["encryptionConfiguration"]["kmsKey"]=params["EncryptionConfiguration"]["KmsKey"]
   return response
  result={"create":{"function":"create_repository","parameters":_create_params},"delete":{"function":"delete_repository","parameters":{"repositoryName":"RepositoryName"}}}
  return result
# Created by pyminifier (https://github.com/liftoff/pyminifier)
